/*
Example for Fram_2 Click

    Date          : Jul 2017.
    Author        : Djordje Rosic

Test configuration FT90x :
    
    MCU             : FT900
    Dev. Board      : EasyFT90x v7 
    SW              : mikroC PRO for FT90x v.2.2.1

Description :


    This example demonstrates the use of FRAM 2 click. It will first initialize
    peripherals and enable writing to FRAM. It will then write the value 42
    into register 0x10, and then read that value and output it via UART.

    Note: Turn on the UART switches on the board to enable uart output.

*/


#include <stdint.h>

sbit FRAM2_CS         at GPIO_PIN28_bit;

static void Fram_2_Write (uint8_t address1, uint8_t address2,
                          uint8_t address3, uint8_t writeData);
static uint8_t Fram_2_Read (uint8_t address1,
                            uint8_t address2, uint8_t address3);

void systemInit()
{
    GPIO_Digital_Output( &GPIO_PORT_24_31, _GPIO_PINMASK_4 );
    SPIM1_Init_Advanced(_SPI_MASTER_CLK_RATIO_256,
     _SPI_CFG_PHASE_CAPTURE_RISING | _SPI_CFG_POLARITY_IDLE_HIGH |
     _SPI_CFG_SS_AUTO_DISABLE | _SPI_CFG_FIFO_DISABLE, _SPI_SS_LINE_NONE);

    UART1_Init ( 9600);
    UART_Write_Text ("\r\nInitialized");
}

void Fram_2_Init()
{
    FRAM2_CS = 0;
    SPIM_Write (0x06); //Write enable command is required prior to any write.
    FRAM2_CS = 1;
}

void Fram_2_Task()
{
    uint8_t readData;
    char outputText [5];
    memset ( outputText, 0, 5);
    UART_Write_Text ("\r\nWriting value 42 into register 0x10...");
    Fram_2_Write (0x00, 0x00, 0x10, 42 );

    UART_Write_Text ("\r\nReading from register 0x10...");
    readData = Fram_2_Read  (0x00, 0x00, 0x10);
    ShortToStr (readData, outputText);
    UART_Write_Text ("\r\nRead value: ");
    UART_Write_Text (outputText);
}

void main()
{
    systemInit();
    Fram_2_Init();

    Fram_2_Task();
}

static void Fram_2_Write (uint8_t address1, uint8_t address2,
                          uint8_t address3, uint8_t writeData)
{
    FRAM2_CS = 0;
    SPIM_Write (0x02);             //Write OPcode
    SPIM_Write (address1);
    SPIM_Write (address2);
    SPIM_Write (address3);
    SPIM_Write (writeData);
    //More data can be written after this. Address pointer is auto-incremented.
    FRAM2_CS = 1;
}
static uint8_t Fram_2_Read (uint8_t address1,
                            uint8_t address2, uint8_t address3)
{
    FRAM2_CS = 0;
    SPIM_Write (0x03);             //Read OPcode
    SPIM_Write (address1);
    SPIM_Write (address2);
    SPIM_Write (address3);
    return SPIM_Read (0x00);
    //More data can be read after this. Address pointer is auto-incremented.
    FRAM2_CS = 1;
}